@@ -3,11 +3,15 @@
 # License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
 
 from __future__ import division
-import time, datetime, json
+import time
+import datetime
+import json
+
 import anki.js
 from anki.utils import fmtTimeSpan, ids2str
 from anki.lang import _, ngettext
 
+
 # Card stats
 ##########################################################################
 
@@ -56,6 +60,8 @@ class CardStats(object):
         self.addLine(_("Card Type"), c.template()['name'])
         self.addLine(_("Note Type"), c.model()['name'])
         self.addLine(_("Deck"), self.col.decks.name(c.did))
+        self.addLine(_("Note ID"), c.nid)
+        self.addLine(_("Card ID"), c.id)
         self.txt += "</table>"
         return self.txt
 
@@ -341,14 +347,16 @@ group by day order by day""" % (self._limit(), lim),
             tot *= 60
         self._line(i, _("Average for days studied"), self._avgDay(
             tot, studied, unit))
-        self._line(i, _("If you studied every day"), self._avgDay(
-            tot, period, unit))
+        if studied != period:
+            # don't display if you did study every day
+            self._line(i, _("If you studied every day"), self._avgDay(
+                tot, period, unit))
         if total and tot:
             perMin = total / float(tot)
             perMin = ngettext("%d card/minute", "%d cards/minute", perMin) % perMin
             self._line(
                 i, _("Average answer time"),
-                "%0.1fs (%s)" % ((tot*60)/total, perMin))
+                _("%(a)0.1fs (%(b)s)") % dict(a=(tot*60)/total, b=perMin))
         return self._lineTbl(i), int(tot)
 
     def _splitRepData(self, data, spec):
@@ -697,7 +705,7 @@ select
 sum(case when queue=2 and ivl >= 21 then 1 else 0 end), -- mtr
 sum(case when queue in (1,3) or (queue=2 and ivl < 21) then 1 else 0 end), -- yng/lrn
 sum(case when queue=0 then 1 else 0 end), -- new
-sum(case when queue=-1 then 1 else 0 end) -- susp
+sum(case when queue<0 then 1 else 0 end) -- susp
 from cards where did in %s""" % self._limit())
 
     # Footer
@@ -779,7 +787,7 @@ font-weight: bold;
 
 <td>
 <center><div id=%(id)sLegend></div></center>
-<div id="%(id)s" style="width:%(w)s; height:%(h)s;"></div>
+<div id="%(id)s" style="width:%(w)spx; height:%(h)spx;"></div>
 </td>
 
 <td><div style="width: 150px; text-align: center; position:absolute;
