@@ -167,9 +167,11 @@ AnkiWeb is too busy at the moment. Please try again in a few minutes.""")
             return _("504 gateway timeout error received. Please try temporarily disabling your antivirus.")
         elif "code: 409" in err:
             return _("Only one client can access AnkiWeb at a time. If a previous sync failed, please try again in a few minutes.")
-        elif "10061" in err or "10013" in err:
+        elif "10061" in err or "10013" in err or "10053" in err:
             return _(
                 "Antivirus or firewall software is preventing Anki from connecting to the internet.")
+        elif "10054" in err or "Broken pipe" in err:
+            return _("Connection timed out. Either your internet connection is experiencing problems, or you have a very large file in your media folder.")
         elif "Unable to find the server" in err:
             return _(
                 "Server not found. Either your connection is down, or antivirus/firewall "
@@ -178,6 +180,8 @@ AnkiWeb is too busy at the moment. Please try again in a few minutes.""")
             return _("Proxy authentication required.")
         elif "code: 413" in err:
             return _("Your collection or a media file is too large to sync.")
+        elif "EOF occurred in violation of protocol" in err:
+            return _("Error establishing a secure connection. This is usually caused by filtering software, or problems with your ISP.")
         return err
 
     def _getUserPass(self):
@@ -448,46 +452,53 @@ httplib.HTTPConnection.send = _incrementalSend
 # this is an augmented version of httplib's request routine that:
 # - doesn't assume requests will be tried more than once
 # - calls a hook for each chunk of data so we can update the gui
+# - retries only when keep-alive connection is closed
 def _conn_request(self, conn, request_uri, method, body, headers):
-    try:
-        if conn.sock is None:
-          conn.connect()
-        conn.request(method, request_uri, body, headers)
-    except socket.timeout:
-        raise
-    except socket.gaierror:
-        conn.close()
-        raise httplib2.ServerNotFoundError(
-            "Unable to find the server at %s" % conn.host)
-    except httplib2.ssl_SSLError:
-        conn.close()
-        raise
-    except socket.error, e:
-        conn.close()
-        raise
-    except httplib.HTTPException:
-        conn.close()
-        raise
-    try:
-        response = conn.getresponse()
-    except (socket.error, httplib.HTTPException):
-        raise
-    else:
-        content = ""
-        if method == "HEAD":
-            response.close()
+    for i in range(2):
+        try:
+            if conn.sock is None:
+              conn.connect()
+            conn.request(method, request_uri, body, headers)
+        except socket.timeout:
+            raise
+        except socket.gaierror:
+            conn.close()
+            raise httplib2.ServerNotFoundError(
+                "Unable to find the server at %s" % conn.host)
+        except httplib2.ssl_SSLError:
+            conn.close()
+            raise
+        except socket.error, e:
+            conn.close()
+            raise
+        except httplib.HTTPException:
+            conn.close()
+            raise
+        try:
+            response = conn.getresponse()
+        except httplib.BadStatusLine:
+            print "retry bad line"
+            conn.close()
+            conn.connect()
+            continue
+        except (socket.error, httplib.HTTPException):
+            raise
         else:
-            buf = StringIO()
-            while 1:
-                data = response.read(CHUNK_SIZE)
-                if not data:
-                    break
-                buf.write(data)
-                runHook("httpRecv", len(data))
-            content = buf.getvalue()
-        response = httplib2.Response(response)
-        if method != "HEAD":
-            content = httplib2._decompressContent(response, content)
-    return (response, content)
+            content = ""
+            if method == "HEAD":
+                response.close()
+            else:
+                buf = StringIO()
+                while 1:
+                    data = response.read(CHUNK_SIZE)
+                    if not data:
+                        break
+                    buf.write(data)
+                    runHook("httpRecv", len(data))
+                content = buf.getvalue()
+            response = httplib2.Response(response)
+            if method != "HEAD":
+                content = httplib2._decompressContent(response, content)
+        return (response, content)
 
 httplib2.Http._conn_request = _conn_request
